% ########################################################################
%  ATTENTION
% ########################################################################
%
%  This software is for guidance only. It is provided "as is".
%  It only aims at providing coding information to the customer in order
%  for them to save time. As a result no warranties, whether express, 
%  implied or statutory, including, but not limited to implied warranties 
%  of merchantability and fitness for a particular purpose apply 
%  to this software.
%  A·P·E Angewandte Physik und Elektronik GmbH shall not be held liable 
%  for any direct, indirect or consequential damages with respect to any 
%  claims arising from the content of such sourcecode and/or the use made 
%  by customers of the coding information contained herein in connection
%  with their products.
%
%  File Version: 1.0
%
%  Changelog:
%    1.0 - Initial Version
%
% ########################################################################

%clear workspace
clear;

% Create new APEDevice instance (Host/IP, TCP-Port, r/w-timeout in seconds)
myDevice = ape_device('172.16.0.36', 51123, 10.0);

% query SCPI *IDN Information
disp('Requesting Device Information...');
disp(myDevice.idn()) 

% query software version
disp('Requesting Software Version Number...');
disp(myDevice.query('system:software?'))
% query spectrum data
disp('Requesting spectrum data...');

% query the spectrum data
% spectrum:data? returns an scpi block -> set 2nd parameter to "true" to
% enable automatic scpi block handling
%
% scpi block data is returned data as char-array (string). 
% to unpack the data it must be converted to an uint8-array fist!
[x,y] = scpi_to_dbl_array(uint8(myDevice.query('spectrum:data?',true)));

% plot the extracted data
disp('Data received...plotting spectrum')

figure(1)
plot(x,y);
xlabel('Wavelength [nm]');
ylabel('Intensity [a.u.]');
title('waveScan USB - Spectrum');

% close the tcp connection to the device
myDevice.close()